==> uniq-1.2.0.25-py3-none-any.whl: uniq/apis/nb/clients/network_discovery_client/models/NetworkDeviceReachabilityInfoNIO.py <==
#!/usr/bin/env python
#pylint: skip-file
"""
Copyright 2016 Cisco Systems

Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

    http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.
"""

class NetworkDeviceReachabilityInfoNIO(object):



    def __init__(self):
        """
        Attributes:
          swaggerTypes (dict): The key is attribute name and the value is attribute type.
          attributeMap (dict): The key is attribute name and the value is json key in definition.
        """
        self.swaggerTypes = {

            'discoveryId': 'str',


            'protocolUsed': 'str',


            'discoveryStartTime': 'str',


            'mgmtIp': 'str',


            'protocolList': 'str',


            'snmpCommunity': 'str',


            'userName': 'str',


            'password': 'str',


            'id': 'str',


            'enablePassword': 'str',


            'reachabilityFailureReason': 'str',


            'reachabilityStatus': 'str',


            'attributeInfo': 'object'

        }

        self.attributeMap = {

            'discoveryId': 'discoveryId',

            'protocolUsed': 'protocolUsed',

            'discoveryStartTime': 'discoveryStartTime',

            'mgmtIp': 'mgmtIp',

            'protocolList': 'protocolList',

            'snmpCommunity': 'snmpCommunity',

            'userName': 'userName',

            'password': 'password',

            'id': 'id',

            'enablePassword': 'enablePassword',

            'reachabilityFailureReason': 'reachabilityFailureReason',

            'reachabilityStatus': 'reachabilityStatus',

            'attributeInfo': 'attributeInfo'

        }



        self.discoveryId = None # str


        self.protocolUsed = None # str


        self.discoveryStartTime = None # str


        self.mgmtIp = None # str


        self.protocolList = None # str


        self.snmpCommunity = None # str


        self.userName = None # str


        self.password = None # str


        self.id = None # str


        self.enablePassword = None # str


        self.reachabilityFailureReason = None # str


        self.reachabilityStatus = None # str


        self.attributeInfo = None # object

==> uniq-1.4.0.36-py3-none-any.whl: uniq/apis/nb/clients/network_discovery_client/models/NetworkDeviceReachabilityInfoNIO.py <==
#!/usr/bin/env python
#pylint: skip-file
# This source code is licensed under the Apache license found in the
# LICENSE file in the root directory of this project.


class NetworkDeviceReachabilityInfoNIO(object):


    def __init__(self):
        """
        Attributes:
          swaggerTypes (dict): The key is attribute name and the value is attribute type.
          attributeMap (dict): The key is attribute name and the value is json key in definition.
        """
        self.swaggerTypes = {
            
            'snmpCommunity': 'str',
            
            
            'mgmtIp': 'str',
            
            
            'protocolList': 'str',
            
            
            'protocolUsed': 'str',
            
            
            'discoveryStartTime': 'str',
            
            
            'userName': 'str',
            
            
            'password': 'str',
            
            
            'id': 'str',
            
            
            'discoveryId': 'str',
            
            
            'reachabilityFailureReason': 'str',
            
            
            'reachabilityStatus': 'str',
            
            
            'enablePassword': 'str',
            
            
            'attributeInfo': 'dict'
            
        }

        self.attributeMap = {
            
            'snmpCommunity': 'snmpCommunity',
            
            'mgmtIp': 'mgmtIp',
            
            'protocolList': 'protocolList',
            
            'protocolUsed': 'protocolUsed',
            
            'discoveryStartTime': 'discoveryStartTime',
            
            'userName': 'userName',
            
            'password': 'password',
            
            'id': 'id',
            
            'discoveryId': 'discoveryId',
            
            'reachabilityFailureReason': 'reachabilityFailureReason',
            
            'reachabilityStatus': 'reachabilityStatus',
            
            'enablePassword': 'enablePassword',
            
            'attributeInfo': 'attributeInfo'
            
        }       

        
        #SNMP community used for device connectivity
        
        self.snmpCommunity = None # str
        
        #IP address of the device
        
        self.mgmtIp = None # str
        
        #Protocol order given for discovery
        
        self.protocolList = None # str
        
        #Protocol used for device discovery
        
        self.protocolUsed = None # str
        
        #Time when the discovery was started
        
        self.discoveryStartTime = None # str
        
        #CLI username used for device connectivity
        
        self.userName = None # str
        
        #CLI password used for device connectivity
        
        self.password = None # str
        
        #Unique identifier for reachability-info
        
        self.id = None # str
        
        #ID of discovery thorugh which device was discovered
        
        self.discoveryId = None # str
        
        #Reason for failure if the device is not discovered successfully
        
        self.reachabilityFailureReason = None # str
        
        #Reachability status of the device as Reachable / Unreachable
        
        self.reachabilityStatus = None # str
        
        #CLI enable password used for device connectivity
        
        self.enablePassword = None # str
        
        
        self.attributeInfo = None # dict
